@@ -28,6 +28,7 @@
 import os
 import requests
 import imp
+from webob import exc
 from wtforms import Form
 from wtforms.fields import (SelectField, TextField, BooleanField, IntegerField,
                             PasswordField)
@@ -229,7 +230,7 @@ class ValidationServerForm(ConfigForm):
     client_id = IntegerField('Client ID', [NumberRange(0)])
     client_secret = TextField('API key')
     server_list = ListField(
-        'Validation Server URLs', [URL()],
+        'Validation Server URLs', [URL(require_tld=False)],
         description="""
         List of URLs to YubiKey validation servers.
         Example: <code>http://example.com/wsapi/2.0/verify</code>
@@ -313,6 +314,10 @@ class YubiAuthApp(App):
         if using_default_client():
             yield panel('YubiAuth', 'Using default YubiCloud client!',
                         '/%s/otp' % self.name, 'danger')
+        if using_ldap():
+            yield panel('YubiAuth',
+                        'Using LDAP: %s' % auth_config['ldap_server'],
+                        '/%s/password' % self.name, 'info')
 
     def general(self, request):
         return self.render_forms(request, [SecurityForm()],
@@ -356,7 +361,7 @@ class YubiAuthApp(App):
     def advanced(self, request):
         return self.render_forms(request, [
             FileForm(AUTH_CONFIG_FILE, 'Configuration', lang='python')
-        ], script='editor')
+        ], scripts=['editor'])
 
     def users(self, request):
         """
@@ -371,7 +376,12 @@ class YubiAuthApp(App):
 
         with YubiAuth() as auth:
             app = YubiAuthUsers(auth)
-            return app(request).prerendered
+            try:
+                return app(request).prerendered
+            except (exc.HTTPOk, exc.HTTPRedirection) as e:
+                # Ensure auth is closed on 200-300 codes.
+                exception = e
+        raise exception
 
     # Pulls the tab to the right:
     advanced.advanced = True
